==> seedsui-react-5.8.64.tgz: package/lib/Picker/Main/utils/formatValue.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import _ from 'lodash';

// 格式化值
function formatValue(value, _ref) {
  var lists = _ref.lists,
    listCount = _ref.listCount;
  var newValue = _.cloneDeep(value);
  if (!Array.isArray(value)) {
    newValue = _toConsumableArray(Array(listCount)).map(function (item, slotIndex) {
      return lists[slotIndex][0];
    });
    return newValue;
  }

  // 如果项数少，填充数组
  if (newValue.length < listCount) {
    newValue = _toConsumableArray(Array(listCount)).map(function (item, slotIndex) {
      if (!(value !== null && value !== void 0 && value[slotIndex])) {
        return lists[slotIndex][0];
      }
      return value[slotIndex];
    });
  }
  // 如果项数多，减少数组
  else if (newValue.length > listCount) {
    newValue = newValue.slice(0, listCount);
  }
  return newValue;
}
export default formatValue;

==> seedsui-react-5.8.79.tgz: package/lib/Picker/Main/utils/formatValue.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import _ from 'lodash';

// 格式化值
function formatValue(value, _ref) {
  var lists = _ref.lists,
    listCount = _ref.listCount;
  var newValue = null;
  if (!Array.isArray(value)) {
    newValue = _toConsumableArray(Array(listCount)).map(function (item, slotIndex) {
      return lists[slotIndex][0];
    });
    return newValue;
  } else {
    newValue = _.cloneDeep(value);
  }

  // 如果项数少，填充数组
  if (newValue.length < listCount) {
    newValue = _toConsumableArray(Array(listCount)).map(function (item, slotIndex) {
      if (!(value !== null && value !== void 0 && value[slotIndex])) {
        return lists[slotIndex][0];
      }
      return value[slotIndex];
    });
  }
  // 如果项数多，减少数组
  else if (newValue.length > listCount) {
    newValue = newValue.slice(0, listCount);
  }
  return newValue;
}
export default formatValue;
